Trait FormatterExt

trait FormatterExt: sealed::Sealed

An extension trait for core::fmt::Formatter.

Required Methods

fn pad_with_width(self: &mut Self, width: usize, args: Arguments<'_>) -> Result

Writes the given arguments to the formatter, padding them with the given width. If width is incorrect, the resulting output will not be the requested width.

Implementors