Trait FormatterExt
trait FormatterExt: sealed::Sealed
An extension trait for core::fmt::Formatter.
Required Methods
fn pad_with_width(self: &mut Self, width: usize, args: Arguments<'_>) -> ResultWrites the given arguments to the formatter, padding them with the given width. If
widthis incorrect, the resulting output will not be the requested width.
Implementors
impl FormatterExt for Formatter<'_>